package com.chinaitop.depot.hardware.basics.controller;

import com.chinaitop.depot.hardware.basics.constant.Constant;
import com.chinaitop.depot.hardware.basics.model.ConfGrating;
import com.chinaitop.depot.hardware.basics.model.ResponseEntity;
import com.chinaitop.depot.hardware.basics.service.ConfGratingService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * @author qingsong.han
 * @description: 出入库光栅硬件配置信息接口
 * @create 2021-06-23 15:21
 */
@RestController
@RequestMapping("/gratingConfig")
@Api(value = "ConfGratingController", description = "光栅硬件配置信息接口类")
public class ConfGratingController {

    @Resource
    private ConfGratingService gratingService;

    @RequestMapping(value = "/gratingSave", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "数据添加", notes = "数据添加")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "gratingJson", value = "数据json串", paramType = "form")
    })
    public ResponseEntity gratingSave(@RequestBody ConfGrating gratingJson) {
        int b = gratingService.save(gratingJson);
        if (b > 0)
            return ResponseEntity.ok();
        else
            return ResponseEntity.failed(Constant.FAILED);
    }

    @RequestMapping(value = "/gratingUpdate", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "数据更新", notes = "数据更新")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "gratingJson", value = "数据json串", paramType = "form")
    })
    public ResponseEntity gratingUpdate(@RequestBody ConfGrating gratingJson) {
        int b = gratingService.update(gratingJson);
        if (b > 0)
            return ResponseEntity.ok();
        else
            return ResponseEntity.failed(Constant.FAILED);
    }

    @RequestMapping(value = "/gratingPageList", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "数据更新", notes = "数据更新")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "form"),
            @ApiImplicitParam(name = "pageSize", value = "每页大小", paramType = "form"),
            @ApiImplicitParam(name = "gratingJson", value = "数据json串", paramType = "form")
    })
    public ResponseEntity gratingPageList(@RequestParam Integer pageNum, @RequestParam Integer pageSize, @ModelAttribute ConfGrating gratingJson) {
        try {
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            PageInfo<ConfGrating> confGratingPageInfo = gratingService.selectList(pageNum, pageSize, gratingJson);
            return ResponseEntity.ok(confGratingPageInfo);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("查询失败!");
        }
    }

    @RequestMapping(value = "/gratingDeleteById", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "数据更新", notes = "数据更新")
    @ApiImplicitParam(name = "id", value = "数据id", paramType = "form")
    public ResponseEntity gratingDeleteById(@RequestParam String id) {
        if (gratingService.deleteById(id) > 0)
            return ResponseEntity.ok();
        else
            return ResponseEntity.failed("删除失败!");
    }


}
