package com.chinaitop.depot.hardware.basics.controller;

import com.chinaitop.depot.hardware.basics.model.ResponseEntity;
import com.chinaitop.depot.hardware.basics.model.TEnergyInfo;
import com.chinaitop.depot.hardware.basics.service.EnergyDetectionService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author hf
 * @description: 能耗检测
 * @create 2018-12-11 10:57
 */
@RestController
@RequestMapping(value = "/intelligents/energyDetection")
@Api(value = "EnergyDetectionController", description = "能耗检测控制类")
@SuppressWarnings("all")
public class EnergyDetectionController {

    @Resource
    private EnergyDetectionService energyDetectionService;

    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;


    
    /**
     * 能耗电表查询
     * @param pageNum
     * @param pageSize
     * @param orgId
     * @param deviceNumber
     * @return
     */
    @RequestMapping(value = "/queryMeterList", method = RequestMethod.GET)
    @ApiOperation(value = "能耗电表查询", notes = "能耗电表查询")
    @ApiImplicitParams({
    	@ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
    	@ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
    	@ApiImplicitParam(name = "orgId", value = "机构Id", paramType = "query"),
    	@ApiImplicitParam(name = "deviceNumber", value = "设备编码", paramType = "query")
    })
    public ResponseEntity<PageInfo<TEnergyInfo>> queryMeterList(Integer pageNum, Integer pageSize, Integer orgId, String deviceNumber) {
    	List<TEnergyInfo> list = null;
    	try {
    		if (null != pageNum && null != pageSize) {
    			PageHelper.startPage(pageNum, pageSize);
    		}
    		
    		list = energyDetectionService.queryMeter( orgId,  deviceNumber);
    	} catch (Exception e) {
    		e.printStackTrace();
    		ResponseEntity.failed(e.getMessage());
    	}
    	PageInfo<TEnergyInfo> pageInfo = new PageInfo<TEnergyInfo>(list);
    	return ResponseEntity.ok(pageInfo);
    }
    

    /**
     * 根据id删除
     * @param id
     * @return
     */
    @RequestMapping(value = "/deleteById", method = RequestMethod.POST)
    public ResponseEntity deleteById(String id, String ammeterJson) {
        if (StringUtils.isNotBlank(id)) {
            int count = energyDetectionService.deleteById(id, ammeterJson);
            if (count > 0) {
                ResponseEntity.ok();
                return ResponseEntity.ok();
            } else {
                return ResponseEntity.failed("删除失败!");
            }
        }
        return ResponseEntity.failed("ID数据有误!");
    }
    
    /**
     * 根据id查询信息
     * @param id
     * @return
     */
    @RequestMapping(value = "/getById", method = RequestMethod.GET)
    @ApiOperation(value = "根据id查询电表信息", notes = "根据id查询电表信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "电表id", paramType = "query")
    })
    public ResponseEntity<TEnergyInfo> getById(String id) {
    	TEnergyInfo tEnergyInfo = null;
        if (StringUtils.isNotBlank(id)) {
        	tEnergyInfo = energyDetectionService.getById(id);
        } else {
            return ResponseEntity.failed("ID数据有误!");
        }
        return ResponseEntity.ok(tEnergyInfo);
    }
    
    /**
     * 验证编码是否重复
     * @param id
     * @param vNhCode
     * @return
     */
    @RequestMapping(value = "/validCode", method = RequestMethod.GET)
    @ApiOperation(value = "根据id查询电表信息", notes = "根据id查询电表信息")
    @ApiImplicitParams({
    	@ApiImplicitParam(name = "id", value = "电表id", paramType = "query"),
    	@ApiImplicitParam(name = "vNhCode", value = "电表编码", paramType = "query")
    })
    public ResponseEntity<TEnergyInfo> validCode(String id,String vNhCode) {
    	Map<String,Object> map = new HashMap<String,Object>();
        map.put("id", id);
        map.put("vNhCode", vNhCode);
    	TEnergyInfo tEnergyInfo = energyDetectionService.validCode(map);
    	return ResponseEntity.ok(tEnergyInfo);
    }
    
    /**
     * 保存数据
     * @param tEnergyInfoJson
     * @return
     */
    @RequestMapping(value = "/saveAmmeter", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    public ResponseEntity saveAmmeter(String tEnergyInfoJson) {
        try {
        	// JSON字符串转对象
    		TEnergyInfo tEnergyInfo = (TEnergyInfo) JsonToObjectUtils.jsonToObject(tEnergyInfoJson,"com.chinaitop.depot.hardware.basics.model.TEnergyInfo");
    		tEnergyInfo.setvUpdateTime(new Date());
            // 获取Max+1值
            Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_energy_info", "v_zd_code", "v_nh_code", null);
            tEnergyInfo.setvNhCode(valueMax.get("column2").toString());
    		if (StringUtils.isBlank(tEnergyInfo.getId())) {
    			energyDetectionService.add(tEnergyInfo);
            } else {
    			energyDetectionService.update(tEnergyInfo);
            }
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("更新失败");
        }
        return ResponseEntity.ok();
    }

}
