package com.chinaitop.depot.hardware.basics.controller;

import com.chinaitop.depot.hardware.basics.model.ResponseEntity;
import com.chinaitop.depot.hardware.basics.model.TNRoomInfo;
import com.chinaitop.depot.hardware.basics.service.NitrogenService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping(value = "/intelligents/nitrogen")
@Api(value = "NitrogenController", description = "氮气房设备控制类")
public class NitrogenController {

    @Resource
    private NitrogenService nitrogenService;

    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "查询 氮气房设备 信息列表", notes = "查询 氮气房设备 信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "rName", value = "氮气房名称", paramType = "query")
    })
    public ResponseEntity<PageInfo<TNRoomInfo>> getList(Integer pageNum, Integer pageSize, String rName) {
        List<TNRoomInfo> list = null;
        try {
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            list = nitrogenService.getList(rName);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("查询氮气房列表失败");
        }
        PageInfo<TNRoomInfo> pageInfo = new PageInfo<TNRoomInfo>(list);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/getById", method = RequestMethod.POST)
    @ApiOperation(value = "根据氮气房id查询 信息", notes = "根据氮气房id查询 信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "气体id", paramType = "query")
    })
    public ResponseEntity<TNRoomInfo> getById(String id) {
        TNRoomInfo tnRoomInfo = null;
        if (StringUtils.isNotBlank(id)) {
            tnRoomInfo = nitrogenService.getById(id);
        } else {
            return ResponseEntity.failed("ID数据有误!");
        }
        return ResponseEntity.ok(tnRoomInfo);
    }

    @RequestMapping(value = "/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "数据更新与添加", notes = "数据更新与添加")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "grainJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity save(String grainJson) {
        try {
            nitrogenService.save(grainJson);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("保存失败");
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/deleteById", method = RequestMethod.POST)
    @ApiOperation(value = "根据氮气房id删除", notes = "根据氮气房id删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "气体id", paramType = "query"),
            @ApiImplicitParam(name = "basicRoomSetJson", value = "气体推送数据json", paramType = "query")
    })
    public ResponseEntity deleteById(String id, String basicRoomSetJson) {
        if (StringUtils.isNotBlank(id)) {
            int count = nitrogenService.deleteById(id, basicRoomSetJson);
            if (count > 0) {
                return ResponseEntity.ok();
            } else {
                return ResponseEntity.failed("删除失败!");
            }
        }
        return ResponseEntity.failed("ID数据有误!");
    }
    @RequestMapping(value = "/getBycfCode", method = RequestMethod.GET)
    @ApiOperation(value = "校验是否重复", notes = "校验是否重复")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "vdevcode", value = "设备编码", paramType = "query"),
            @ApiImplicitParam(name = "vdevname", value = "设备名称", paramType = "query")
    })
    public ResponseEntity getBycfCode(String vdevcode, String vdevname) {
        boolean bycfCode = nitrogenService.getBycfCode(vdevcode, vdevname);
        return ResponseEntity.ok(bycfCode);
    }
}
