package com.chinaitop.depot.hardware.basics.controller;

import com.chinaitop.depot.hardware.basics.model.ResponseEntity;
import com.chinaitop.depot.hardware.basics.model.TJctable;
import com.chinaitop.depot.hardware.basics.service.NumberService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

@RestController
@RequestMapping(value = "/intelligents/number")
@Api(value = "InsectController", description = "数量设备控制类")
public class NumberController {

    @Resource
    private NumberService numberService;

    @RequestMapping(value = "/getList", method = RequestMethod.GET)
    @ApiOperation(value = "查询 数量设备 信息列表", notes = "查询 数量设备 信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "vCfCode", value = "仓库名称", paramType = "query")
    })
    public ResponseEntity<PageInfo<TJctable>> getList(Integer pageNum, Integer pageSize, String vCfCode) {
        List<TJctable> list = null;
        try {
            if (null != pageNum && null != pageSize) {
                PageHelper.startPage(pageNum, pageSize);
            }
            list = numberService.getList(vCfCode);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("查询数量列表失败");
        }
        PageInfo<TJctable> pageInfo = new PageInfo<TJctable>(list);
        return ResponseEntity.ok(pageInfo);
    }

    @RequestMapping(value = "/getById", method = RequestMethod.POST)
    @ApiOperation(value = "根据数量id查询 信息", notes = "根据数量id查询 信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "数量id", paramType = "query")
    })
    public ResponseEntity<TJctable> getById(String id) {
        TJctable tNtinfo = null;
        if (StringUtils.isNotBlank(id)) {
            tNtinfo = numberService.getById(id);
        } else {
            return ResponseEntity.failed("ID数据有误!");
        }
        return ResponseEntity.ok(tNtinfo);
    }

    @RequestMapping(value = "/save", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.POST)
    @ApiOperation(value = "数据更新与添加", notes = "数据更新与添加")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "grainJson", value = "表数据json串", paramType = "form")
    })
    public ResponseEntity save(String grainJson) {
        try {
            numberService.save(grainJson);
        } catch (Exception e) {
            e.printStackTrace();
            return ResponseEntity.failed("保存失败");
        }
        return ResponseEntity.ok();
    }

    @RequestMapping(value = "/deleteById", method = RequestMethod.POST)
    @ApiOperation(value = "根据数量id删除", notes = "根据数量id删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "气体id", paramType = "query"),
            @ApiImplicitParam(name = "insectJson", value = "推送删除数据", paramType = "query")
    })
    public ResponseEntity deleteById(String id, String insectJson) {
        if (StringUtils.isNotBlank(id)) {
            int count = numberService.deleteById(id, insectJson);
            if (count > 0) {
                return ResponseEntity.ok();
            } else {
                return ResponseEntity.failed("删除失败!");
            }
        }
        return ResponseEntity.failed("ID数据有误!");
    }
    @RequestMapping(value = "/getBycfCode", method = RequestMethod.GET)
    @ApiOperation(value = "校验是否重复", notes = "校验是否重复")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "vdevcode", value = "设备编码", paramType = "query"),
            @ApiImplicitParam(name = "vdevname", value = "设备名称", paramType = "query")
    })
    public ResponseEntity getBycfCode(String vdevcode, String vdevname) {
        boolean bycfCode = numberService.getBycfCode(vdevcode, vdevname);
        return ResponseEntity.ok(bycfCode);
    }

}
