package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TCtldevinfoMapper;
import com.chinaitop.depot.hardware.basics.model.TCtldevinfo;
import com.chinaitop.depot.hardware.basics.model.TCtldevinfoExample;
import com.chinaitop.depot.hardware.basics.service.AerationParameterService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;

import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class AerationParameterServiceImpl implements AerationParameterService {
    @Resource
    private TCtldevinfoMapper tCtldevinfoMapper;
	@Resource
	private WareHouseBasicInfoService wareHouseBasicInfoService;
	@Resource
    private UuidUtils uUidUtils;
   

    @Override
    public List<TCtldevinfo> getList(String orgId,String vcfcode) {
    	TCtldevinfoExample tCtldevinfoExample = new TCtldevinfoExample();
    	tCtldevinfoExample.setDistinct(true);
    	TCtldevinfoExample.Criteria criteria = tCtldevinfoExample.createCriteria();
		if (StringUtils.isNotEmpty(orgId)) {
			criteria.andOrgIdEqualTo(Integer.valueOf(orgId));
		}
        if (StringUtils.isNotEmpty(vcfcode)) {
            criteria.andVcfcodeEqualTo(vcfcode);
        }
        criteria.andDelFlagEqualTo(1);//未删除
        //tCtldevinfoExample.setOrderByClause("v_update_time desc");
        return tCtldevinfoMapper.selectByExample(tCtldevinfoExample);
    }



    //保存
    @Transactional(rollbackFor = Exception.class)
	@Override
	public void save(String aerationParameterJson,Integer orgId) {
		if (StringUtils.isNotBlank(aerationParameterJson)) {
			TCtldevinfo tCtldevinfo = (TCtldevinfo) JsonToObjectUtils.jsonToObject(aerationParameterJson, "com.chinaitop.depot.intelligent.ventilation.model.TCtldevinfo");
			//String vdevkindcode = tCtldevinfo.getVdevkindcode();
        	//tCtldevinfo.setVdevkindcode(vdevkindcode);
        	tCtldevinfo.setOrgId(orgId);
			if (StringUtils.isNotBlank(tCtldevinfo.getId())) {
            	tCtldevinfoMapper.updateByPrimaryKey(tCtldevinfo);
			} else {
				// 获取Max+1值
				Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_ctldevinfo", "sitecode", "vdevcode", null);
				tCtldevinfo.setVdevcode(valueMax.get("column2").toString());
				tCtldevinfo.setId(uUidUtils.getCode());
				tCtldevinfo.setDelFlag(1); //未删除
                tCtldevinfoMapper.insert(tCtldevinfo);
			}
        }
	}


    //删除
	@Transactional(rollbackFor = Exception.class)
	@Override
	public int deleteById(String id, String aerationParamJson) {
		TCtldevinfo tCtldevinfo = (TCtldevinfo) JsonToObjectUtils.jsonToObject(aerationParamJson, "com.chinaitop.depot.intelligent.ventilation.model.TCtldevinfo");
		tCtldevinfo.setDelFlag(0); //删除
		//int i = tCtldevinfoMapper.deleteByPrimaryKey(id);
		int i = tCtldevinfoMapper.updateByPrimaryKeySelective(tCtldevinfo);
		return i;
	}



	//根据id查找
	@Override
	public TCtldevinfo getById(String id) {
		// TODO Auto-generated method stub
		return tCtldevinfoMapper.selectByPrimaryKey(id);
	}



	//根据仓房查找设备信息
	@Override
	public List<TCtldevinfo> getBycf(Map<String, Object> modelMap) {
		// TODO Auto-generated method stub
		return tCtldevinfoMapper.selectBycf(modelMap);
	}

	

	public TCtldevinfo getVinfo(String vdevcode) {
		TCtldevinfoExample example = new TCtldevinfoExample();
		TCtldevinfoExample.Criteria criteria = example.createCriteria();
		if (StringUtils.isNotEmpty(vdevcode)) {
			criteria.andVdevcodeEqualTo(vdevcode);
		}
		List<TCtldevinfo> infos = tCtldevinfoMapper.selectByExample(example);
		if (infos.size() > 0) {
			return infos.get(0);
		}
		return null;
	}
}
