package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.CardReaderEquipmentMapper;
import com.chinaitop.depot.hardware.basics.model.CardReaderEquipment;
import com.chinaitop.depot.hardware.basics.model.CardReaderEquipmentExample;
import com.chinaitop.depot.hardware.basics.service.CardService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

@Service
public class CardServiceImpl implements CardService {
    @Resource
    private CardReaderEquipmentMapper equipmentMapper;

    @Override
    public List<CardReaderEquipment> getList(String deviceModel) {
        CardReaderEquipmentExample example = new CardReaderEquipmentExample();
        CardReaderEquipmentExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(deviceModel)) {
            criteria.andDeviceModelLike(deviceModel);
        }
        return equipmentMapper.selectByExample(example);
    }

    @Override
    public CardReaderEquipment getById(String id) {
        return equipmentMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            CardReaderEquipment tCcinfo = (CardReaderEquipment) JsonToObjectUtils.jsonToObject(grainJson, CardReaderEquipment.class);
            if (StringUtils.isNotBlank(tCcinfo.getId())) {
                equipmentMapper.updateByPrimaryKey(tCcinfo);
            } else {
                tCcinfo.setId(UuidUtils.getCode());
                equipmentMapper.insert(tCcinfo);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id) {
        int i = equipmentMapper.deleteByPrimaryKey(id);
        return i;
    }

    @Override
    public boolean getBycfCode(String deviceModel) {
        CardReaderEquipmentExample example = new CardReaderEquipmentExample();
        CardReaderEquipmentExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(deviceModel)) {
            criteria.andDeviceModelEqualTo(deviceModel);
        }
        List<CardReaderEquipment> tCcinfos = equipmentMapper.selectByExample(example);
        if (tCcinfos.size() > 0) {
            return true;
        }
        return false;
    }

}
