package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TEnergyInfoMapper;
import com.chinaitop.depot.hardware.basics.model.TEnergyInfo;
import com.chinaitop.depot.hardware.basics.model.TEnergyInfoExample;
import com.chinaitop.depot.hardware.basics.service.EnergyDetectionService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @author hf
 * @description: 能耗检测
 * @create 2018-12-11 11:00
 */
@Service
public class EnergyDetectionServiceImpl implements EnergyDetectionService {


    @Resource
    private TEnergyInfoMapper tEnergyInfoMapper;

    @Resource
    private UuidUtils uUidUtils;


    @Override
    public List<TEnergyInfo> queryMeter(Integer orgId, String deviceNumber) {
        TEnergyInfoExample example = new TEnergyInfoExample();
        TEnergyInfoExample.Criteria criteria = example.createCriteria();
        if (orgId != null) {
            criteria.andOrgIdEqualTo(orgId);
        }
        if (StringUtils.isNotEmpty(deviceNumber)) {
            criteria.andVNhCodeEqualTo(deviceNumber);
        }
        criteria.andDelFlagEqualTo(1);//未删除
        return tEnergyInfoMapper.selectByExample(example);
    }


    @Override
    public int deleteById(String id, String ammeterJson) {
        TEnergyInfo tEnergyInfo = (TEnergyInfo) JsonToObjectUtils.jsonToObject(ammeterJson, TEnergyInfo.class);
        tEnergyInfo.setDelFlag(0); //删除
        int i = tEnergyInfoMapper.updateByPrimaryKeySelective(tEnergyInfo);
        //int i = tEnergyInfoMapper.deleteByPrimaryKey(id);
        return i;
    }

    @Override
    public TEnergyInfo getById(String id) {
        return tEnergyInfoMapper.selectByPrimaryKey(id);
    }

    @Override
    public TEnergyInfo validCode(Map<String, Object> map) {
        return tEnergyInfoMapper.validCode(map);
    }

    @Override
    public void add(TEnergyInfo tEnergyInfo) {
        tEnergyInfo.setDelFlag(1); //未删除
        tEnergyInfo.setId(uUidUtils.getCode());
        tEnergyInfoMapper.insert(tEnergyInfo);
    }

    @Override
    public void update(TEnergyInfo tEnergyInfo) {
        tEnergyInfoMapper.updateByPrimaryKey(tEnergyInfo);
    }

}
