package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TLqinfoMapper;
import com.chinaitop.depot.hardware.basics.model.TLqinfo;
import com.chinaitop.depot.hardware.basics.model.TLqinfoExample;
import com.chinaitop.depot.hardware.basics.service.GrainService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class GrainServiceImpl implements GrainService {
    @Resource
    private TLqinfoMapper tLqinfoMapper;
    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;

    @Override
    public List<TLqinfo> getList(String cfCode) {
        TLqinfoExample example = new TLqinfoExample();
        TLqinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(cfCode)) {
            criteria.andVcfcodeEqualTo(cfCode);
        }
        criteria.andDelFlagEqualTo(1);//未删除
        example.setOrderByClause("vcfcode");
        return tLqinfoMapper.selectByExample(example);
    }

    @Override
    public TLqinfo getById(String id) {
        return tLqinfoMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TLqinfo tLqinfo = (TLqinfo) JsonToObjectUtils.jsonToObject(grainJson, TLqinfo.class);
            if (StringUtils.isNotBlank(tLqinfo.getId())) {
                tLqinfoMapper.updateByPrimaryKey(tLqinfo);

            } else {
            	// 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_lqinfo", "sitecode", "vdevcode", null);
                tLqinfo.setVdevcode(valueMax.get("column2").toString());
                tLqinfo.setId(uUidUtils.getCodeId(tLqinfo.getOrgId(), "t_lqinfo"));
                tLqinfo.setDelFlag(1); //未删除
                tLqinfoMapper.insert(tLqinfo);
            }
        }
        
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id,String basicGrainSetJson) {
    	TLqinfo tLqinfo = (TLqinfo) JsonToObjectUtils.jsonToObject(basicGrainSetJson, TLqinfo.class);
    	tLqinfo.setDelFlag(0); //删除
    	int i = tLqinfoMapper.updateByPrimaryKeySelective(tLqinfo);
    	
        //int i = tLqinfoMapper.deleteByPrimaryKey(id);
        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TLqinfoExample example = new TLqinfoExample();
        TLqinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVdevcodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andVdevnameEqualTo(vdevname);
        }
        List<TLqinfo> tLqinfos = tLqinfoMapper.selectByExample(example);
        if (tLqinfos.size()>0){
            return true;
        }
        return false;
    }
}
