package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TCcinfoMapper;
import com.chinaitop.depot.hardware.basics.model.TCcinfo;
import com.chinaitop.depot.hardware.basics.model.TCcinfoExample;
import com.chinaitop.depot.hardware.basics.service.InsectService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class InsectServiceImpl implements InsectService {
    @Resource
    private TCcinfoMapper tCcinfoMapper;
    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;


    @Override
    public List<TCcinfo> getList(String cfCode) {
        TCcinfoExample example = new TCcinfoExample();
        TCcinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(cfCode)) {
            criteria.andVcfcodeEqualTo(cfCode);
        }
        criteria.andDelFlagEqualTo(1);//未删除
        return tCcinfoMapper.selectByExample(example);
    }

    @Override
    public TCcinfo getById(String id) {
        return tCcinfoMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TCcinfo tCcinfo = (TCcinfo) JsonToObjectUtils.jsonToObject(grainJson, TCcinfo.class);
            if (StringUtils.isNotBlank(tCcinfo.getId())) {
                tCcinfoMapper.updateByPrimaryKey(tCcinfo);
            } else {
                // 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_ccinfo", "sitecode", "vdevcode", null);
                // 替换值
                tCcinfo.setVdevcode(valueMax.get("column2").toString());
                tCcinfo.setId(uUidUtils.getCodeId(tCcinfo.getOrgId(), "t_ccinfo"));
                tCcinfo.setDelFlag(1); //未删除
                tCcinfoMapper.insert(tCcinfo);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id, String insectJson) {
        TCcinfo tCcinfo = (TCcinfo) JsonToObjectUtils.jsonToObject(insectJson, TCcinfo.class);
        tCcinfo.setDelFlag(0);//删除
        int i = tCcinfoMapper.updateByPrimaryKeySelective(tCcinfo);
        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TCcinfoExample example = new TCcinfoExample();
        TCcinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVdevcodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andVdevnameEqualTo(vdevname);
        }
        List<TCcinfo> tCcinfos = tCcinfoMapper.selectByExample(example);
        if (tCcinfos.size() > 0) {
            return true;
        }
        return false;
    }

}
