package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TLedinfoMapper;
import com.chinaitop.depot.hardware.basics.model.TLedinfo;
import com.chinaitop.depot.hardware.basics.model.TLedinfoExample;
import com.chinaitop.depot.hardware.basics.service.LedinfoService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;

import org.springframework.stereotype.Service;
import org.apache.commons.lang.StringUtils;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class LedinfoServiceImpl implements LedinfoService {
    @Resource
    private TLedinfoMapper tLedinfoMapper;
	@Resource
    private UuidUtils uUidUtils;
   

    @Override
    public List<TLedinfo> getList(String orgId) {
    	TLedinfoExample tLedinfoExample = new TLedinfoExample();
    	tLedinfoExample.setDistinct(true);
    	TLedinfoExample.Criteria criteria = tLedinfoExample.createCriteria();
		if (StringUtils.isNotEmpty(orgId)) {
			criteria.andOrgIdEqualTo(Integer.valueOf(orgId));
		}
        return tLedinfoMapper.selectByExample(tLedinfoExample);
    }



    //保存
    @Transactional(rollbackFor = Exception.class)
	@Override
	public void save(String ledinfoJson,Integer orgId) {
		if (StringUtils.isNotBlank(ledinfoJson)) {
			TLedinfo tLedinfo = (TLedinfo) JsonToObjectUtils.jsonToObject(ledinfoJson, "com.chinaitop.depot.hardware.basics.model.TLedinfo");
			if (StringUtils.isNotBlank(tLedinfo.getId())) {
				tLedinfoMapper.updateByPrimaryKey(tLedinfo);
			} else {
				tLedinfo.setId(uUidUtils.getCode());
				tLedinfo.setOrgId(orgId);
				tLedinfoMapper.insert(tLedinfo);
			}
        }
	}


    //删除
	@Transactional(rollbackFor = Exception.class)
	@Override
	public int deleteById(String id) {
		int i = tLedinfoMapper.deleteByPrimaryKey(id);
		return i;
	}


	//根据id查找
	@Override
	public TLedinfo getById(String id) {
		// TODO Auto-generated method stub
		return tLedinfoMapper.selectByPrimaryKey(id);
	}


}
