package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TNRoomInfoMapper;
import com.chinaitop.depot.hardware.basics.model.TNRoomInfo;
import com.chinaitop.depot.hardware.basics.model.TNRoomInfoExample;
import com.chinaitop.depot.hardware.basics.service.NitrogenService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.DateUtils;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class NitrogenServiceImpl implements NitrogenService {
    @Resource
    private TNRoomInfoMapper tnRoomInfoMapper;

    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;

    @Override
    public List<TNRoomInfo> getList(String rName) {
        TNRoomInfoExample example = new TNRoomInfoExample();
        TNRoomInfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(rName)) {
            criteria.andNitrogenhouseLike("%"+rName+"%");
        }
        criteria.andDelFlagEqualTo(1);//未删除
        return tnRoomInfoMapper.selectByExample(example);
    }

    @Override
    public TNRoomInfo getById(String id) {
        return tnRoomInfoMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TNRoomInfo tnRoomInfo = (TNRoomInfo) JsonToObjectUtils.jsonToObject(grainJson, "com.chinaitop.depot.hardware.basics.model.TNRoomInfo");
            tnRoomInfo.setUpdatetime(DateUtils.getDate());
            if (StringUtils.isNotBlank(tnRoomInfo.getId())) {
                tnRoomInfoMapper.updateByPrimaryKey(tnRoomInfo);
            } else {
                // 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_n_room_info", "sitecode", "vdevcode", null);
                tnRoomInfo.setVdevcode(valueMax.get("column2").toString());
                tnRoomInfo.setId(uUidUtils.getCodeId(tnRoomInfo.getOrgId(), "t_n_room_info"));
                tnRoomInfo.setDelFlag(1); //未删除
                tnRoomInfoMapper.insert(tnRoomInfo);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id, String basicRoomSetJson) {
        TNRoomInfo tnRoomInfo = (TNRoomInfo) JsonToObjectUtils.jsonToObject(basicRoomSetJson, "com.chinaitop.depot.hardware.basics.model.TNRoomInfo");
        tnRoomInfo.setDelFlag(0); //删除
        int i = tnRoomInfoMapper.updateByPrimaryKeySelective(tnRoomInfo);
        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TNRoomInfoExample example = new TNRoomInfoExample();
        TNRoomInfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVdevcodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andNitrogenhouseEqualTo(vdevname);
        }
        List<TNRoomInfo> tnRoomInfos = tnRoomInfoMapper.selectByExample(example);
        if (tnRoomInfos.size() > 0) {
            return true;
        }
        return false;
    }
}
