package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TJctableMapper;
import com.chinaitop.depot.hardware.basics.model.TJctable;
import com.chinaitop.depot.hardware.basics.model.TJctableExample;
import com.chinaitop.depot.hardware.basics.service.NumberService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class NumberServiceImpl implements NumberService {
    @Resource
    private TJctableMapper tJctableMapper;
    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;


    @Override
    public List<TJctable> getList(String cfCode) {
        TJctableExample example = new TJctableExample();
        TJctableExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(cfCode)) {
            criteria.andVCfCodeEqualTo(cfCode);
        }
        criteria.andDelFlagEqualTo(1);//未删除
        return tJctableMapper.selectByExample(example);
    }

    @Override
    public TJctable getById(String id) {
        return tJctableMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TJctable tCcinfo = (TJctable) JsonToObjectUtils.jsonToObject(grainJson, TJctable.class);
            if (StringUtils.isNotBlank(tCcinfo.getId())) {
                tJctableMapper.updateByPrimaryKey(tCcinfo);
            } else {
                // 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_ccinfo", "sitecode", "vdevcode", null);
                // 替换值
                tCcinfo.setvJcCode(valueMax.get("column2").toString());
                tCcinfo.setId(uUidUtils.getCodeId(tCcinfo.getOrgId(), "t_ccinfo"));
                tCcinfo.setDelFlag(1); //未删除
                tJctableMapper.insert(tCcinfo);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id, String insectJson) {
        TJctable tCcinfo = (TJctable) JsonToObjectUtils.jsonToObject(insectJson, TJctable.class);
        tCcinfo.setDelFlag(0);//删除
        int i = tJctableMapper.updateByPrimaryKeySelective(tCcinfo);
        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TJctableExample example = new TJctableExample();
        TJctableExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVJcCodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andVJcNameEqualTo(vdevname);
        }
        List<TJctable> tCcinfos = tJctableMapper.selectByExample(example);
        if (tCcinfos.size() > 0) {
            return true;
        }
        return false;
    }

}
