package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TQtdevinfoMapper;
import com.chinaitop.depot.hardware.basics.model.TQtdevinfo;
import com.chinaitop.depot.hardware.basics.model.TQtdevinfoExample;
import com.chinaitop.depot.hardware.basics.service.QtdevinfoService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.DateUtils;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class QtdevinfoServiceImpl implements QtdevinfoService {
    @Resource
    private TQtdevinfoMapper tQtdevinfoMapper;
    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;
    
    
    @Override
    public List<TQtdevinfo> getList(String cfCode) {
        TQtdevinfoExample example = new TQtdevinfoExample();
        TQtdevinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(cfCode)) {
            criteria.andVcfcodeEqualTo(cfCode);
        }
        criteria.andDelFlagEqualTo(1);//未删除
        return tQtdevinfoMapper.selectByExample(example);
    }

    @Override
    public TQtdevinfo getById(String id) {
        return tQtdevinfoMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TQtdevinfo tQtdevinfo = (TQtdevinfo) JsonToObjectUtils.jsonToObject(grainJson, TQtdevinfo.class);
            tQtdevinfo.setUpdatetime(DateUtils.getDate());
            if (StringUtils.isNotBlank(tQtdevinfo.getId())) {
                tQtdevinfoMapper.updateByPrimaryKey(tQtdevinfo);
            } else {
                // 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_qtdevinfo", "sitecode", "vdevcode", null);
                tQtdevinfo.setId(uUidUtils.getCodeId(tQtdevinfo.getOrgId(), "t_qtdevinfo"));
                tQtdevinfo.setVdevcode(valueMax.get("column2").toString());
                tQtdevinfo.setDelFlag(1); //未删除
                tQtdevinfoMapper.insert(tQtdevinfo);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id, String qtDeviInfoJson) {
        TQtdevinfo tQtdevinfo = (TQtdevinfo) JsonToObjectUtils.jsonToObject(qtDeviInfoJson, TQtdevinfo.class);
        tQtdevinfo.setDelFlag(0); //删除
        int i = tQtdevinfoMapper.updateByPrimaryKeySelective(tQtdevinfo);

        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TQtdevinfoExample example = new TQtdevinfoExample();
        TQtdevinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVdevcodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andVdevnameEqualTo(vdevname);
        }
        List<TQtdevinfo> tQtdevinfos = tQtdevinfoMapper.selectByExample(example);
        if (tQtdevinfos.size() > 0) {
            return true;
        }
        return false;
    }

}
