package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TKtinfoMapper;
import com.chinaitop.depot.hardware.basics.model.TKtinfo;
import com.chinaitop.depot.hardware.basics.model.TKtinfoExample;
import com.chinaitop.depot.hardware.basics.service.TKtinfoService;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.utils.DateUtils;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class TKtinfoServiceImpl implements TKtinfoService {
    @Resource
    private TKtinfoMapper tKtinfoMapper;
    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;
    
    
    @Override
    public List<TKtinfo> getList(String vCfCode) {
        TKtinfoExample example = new TKtinfoExample();
        TKtinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vCfCode)) {
           criteria.andVcfcodeEqualTo(vCfCode);
        }
        criteria.andDelFlagEqualTo(1);//未删除
        example.setOrderByClause("updatetime desc");
        return tKtinfoMapper.selectByExample(example);
    }

    @Override
    public TKtinfo getById(String id) {
        return tKtinfoMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TKtinfo tKtinfo = (TKtinfo) JsonToObjectUtils.jsonToObject(grainJson, TKtinfo.class);
            tKtinfo.setUpdatetime(DateUtils.getDate());
            if (StringUtils.isNotBlank(tKtinfo.getId())) {
                tKtinfoMapper.updateByPrimaryKey(tKtinfo);
            } else {
                // 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_ktinfo", "sitecode", "vdevcode", null);
                tKtinfo.setVdevcode(valueMax.get("column2").toString());
                tKtinfo.setId(uUidUtils.getCodeId(tKtinfo.getOrgId(), "t_ktinfo"));
                tKtinfo.setDelFlag(1); //未删除
                tKtinfoMapper.insert(tKtinfo);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id, String ktinfoJson) {
        TKtinfo tKtinfo = (TKtinfo) JsonToObjectUtils.jsonToObject(ktinfoJson, TKtinfo.class);
        tKtinfo.setDelFlag(0); //删除
        int i = tKtinfoMapper.updateByPrimaryKeySelective(tKtinfo);
        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TKtinfoExample example = new TKtinfoExample();
        TKtinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVdevcodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andVdevnameEqualTo(vdevname);
        }
        List<TKtinfo> tKtinfos = tKtinfoMapper.selectByExample(example);
        if (tKtinfos.size() > 0) {
            return true;
        }
        return false;
    }
}
