package com.chinaitop.depot.hardware.basics.service.impl;

import com.chinaitop.depot.hardware.basics.mapper.TWertherinfoMapper;
import com.chinaitop.depot.hardware.basics.model.TWertherinfo;
import com.chinaitop.depot.hardware.basics.model.TWertherinfoExample;
import com.chinaitop.depot.hardware.basics.service.WareHouseBasicInfoService;
import com.chinaitop.depot.hardware.basics.service.WertherinfoService;
import com.chinaitop.depot.hardware.basics.utils.DateUtils;
import com.chinaitop.depot.hardware.basics.utils.JsonToObjectUtils;
import com.chinaitop.depot.hardware.basics.utils.UuidUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
@SuppressWarnings("all")
public class WertherinfoServiceImpl implements WertherinfoService {
    @Resource
    private TWertherinfoMapper tWertherinfoMapper;

    @Resource
    private WareHouseBasicInfoService wareHouseBasicInfoService;
    @Resource
    private UuidUtils uUidUtils;
    
    @Override
    public List<TWertherinfo> getList(String vqxzname, String searchStartDate, String searchEndDate) {
        TWertherinfoExample example = new TWertherinfoExample();
        TWertherinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotBlank(vqxzname)) {
            criteria.andVqxznameLike("%" + vqxzname + "%");
        }
        if (StringUtils.isNotBlank(searchStartDate) && StringUtils.isNotBlank(searchEndDate)) {
            criteria.andUpdatetimeBetween(DateUtils.stringToData(searchStartDate + DateUtils.startTime), DateUtils.stringToData(searchEndDate + DateUtils.endTime));
        }
        criteria.andDelFlagEqualTo(1);//未删除
        example.setOrderByClause("updatetime desc");
        return tWertherinfoMapper.selectByExample(example);
    }

    @Override
    public TWertherinfo getById(String id) {
        return tWertherinfoMapper.selectByPrimaryKey(id);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void save(String grainJson) {
        if (StringUtils.isNotBlank(grainJson)) {
            TWertherinfo tWertherinfo = (TWertherinfo) JsonToObjectUtils.jsonToObject(grainJson, TWertherinfo.class);
            tWertherinfo.setUpdatetime(DateUtils.getDate());
            if (StringUtils.isNotBlank(tWertherinfo.getId())) {
                tWertherinfoMapper.updateByPrimaryKey(tWertherinfo);
            } else {
                // 获取Max+1值
                Map<String, Object> valueMax = wareHouseBasicInfoService.getCode("t_wertherinfo", "sitecode", "vqxzcode", null);
                // 保存数据
                tWertherinfo.setId(uUidUtils.getCodeId(tWertherinfo.getOrgId(), "t_wertherinfo"));
                tWertherinfo.setVqxzcode(valueMax.get("column2").toString());
                tWertherinfo.setDelFlag(1); //未删除
                tWertherinfoMapper.insert(tWertherinfo);
            }
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public int deleteById(String id, String wertherinfojson) {
        TWertherinfo tWertherinfo = (TWertherinfo) JsonToObjectUtils.jsonToObject(wertherinfojson, TWertherinfo.class);
        tWertherinfo.setDelFlag(0); //删除
        int i = tWertherinfoMapper.updateByPrimaryKeySelective(tWertherinfo);
        //int i = tWertherinfoMapper.deleteByPrimaryKey(id);
        return i;
    }

    @Override
    public boolean getBycfCode(String vdevcode, String vdevname) {
        TWertherinfoExample example = new TWertherinfoExample();
        TWertherinfoExample.Criteria criteria = example.createCriteria();
        if (StringUtils.isNotEmpty(vdevcode)) {
            criteria.andVqxzcodeEqualTo(vdevcode);
        }
        if (StringUtils.isNotEmpty(vdevname)) {
            criteria.andVqxznameEqualTo(vdevname);
        }
        List<TWertherinfo> tWertherinfos = tWertherinfoMapper.selectByExample(example);
        if (tWertherinfos.size() > 0) {
            return true;
        }
        return false;
    }
}
